@@ -1,7 +1,7 @@
 # -*- coding:utf-8 -*-
 __author__ = """David Scheliga"""
 __email__ = "david.scheliga@gmx.de"
-__version__ = "1.2.2"
+__version__ = "1.3.0"
 __all__ = [
     "doctest_iter_print",
     "doctest_print",
@@ -951,11 +951,17 @@ _DEFAULT_PANDAS_FORMATS = "{:>g}#{:>g}"
 Default format specifications for index and value columns.
 """
 
+_SOLE_NAN = "NaN"
 _DETECTS_SOLE_NAN_REPRESENTATION = re.compile(r"^\s*NaN\s*$")
 """
 For detecting literal 'NaN' value within Series.
 """
 
+_ENCLOSED_NA = "<NA>"
+_DETECTS_ENCLOSED_NA_REPRESENTATION = re.compile(r"^\s*<NA>\s*$")
+"""
+For detecting literal '<NA>' value within Series.
+"""
 
 _DECODES_FORMAT_SPECIFICATION = re.compile(
     r"{:?(?P<align>[<>=^]?)?"
@@ -1580,7 +1586,7 @@ def _lower_nan_representation(cell_text: str) -> str:
     """
     # In this occasion its all about case sensitivity.
     # noinspection PyPep8Naming
-    fast_path_because_pure_NaN = cell_text == "NaN"
+    fast_path_because_pure_NaN = cell_text == _SOLE_NAN
     if fast_path_because_pure_NaN:
         return "nan"
 
@@ -1589,10 +1595,80 @@ def _lower_nan_representation(cell_text: str) -> str:
     # noinspection PyPep8Naming
     is_sole_NaN_representation = match is not None
     if is_sole_NaN_representation:
-        return cell_text.replace("NaN", "nan")
+        return cell_text.replace(_SOLE_NAN, "nan")
     return cell_text
 
 
+def _replace_enclosed_na_representation(cell_text: str) -> str:
+    """
+
+    Args:
+        cell_text:
+
+    Returns:
+
+    .. doctest::
+
+        >>> # access to private member for testing only
+        >>> # noinspection PyProtectedMember
+        >>> from doctestprinter import _replace_enclosed_na_representation
+        >>> _replace_enclosed_na_representation("<NA>")
+        'nan'
+        >>> _replace_enclosed_na_representation("<NA>   ")
+        'nan   '
+        >>> _replace_enclosed_na_representation(" <NA> ")
+        ' nan '
+        >>> _replace_enclosed_na_representation("  <NA> ")
+        '  nan '
+        >>> _replace_enclosed_na_representation(" <NA> ")
+        ' nan '
+        >>> _replace_enclosed_na_representation(" <NA>")
+        ' nan'
+        >>> _replace_enclosed_na_representation("<NA> ")
+        'nan '
+
+    """
+    # In this occasion its all about case sensitivity.
+    # noinspection PyPep8Naming
+    fast_path_because_pure_Na = cell_text == _ENCLOSED_NA
+    if fast_path_because_pure_Na:
+        return "nan"
+
+    match = _DETECTS_ENCLOSED_NA_REPRESENTATION.match(cell_text)
+    # In this occasion its all about case sensitivity.
+    # noinspection PyPep8Naming
+    is_sole_NaN_representation = match is not None
+    if is_sole_NaN_representation:
+        return cell_text.replace(_ENCLOSED_NA, "nan")
+    return cell_text
+
+
+def _uniform_nan(cell_text: str) -> str:
+    """
+    Uniforms different NaN value representations to 'nan'.
+
+    Args:
+        cell_text(str):
+            The item of an array.
+
+    Returns:
+        str
+
+    .. doctest::
+
+        >>> # access to private member for testing only
+        >>> # noinspection PyProtectedMember
+        >>> from doctestprinter import _uniform_nan
+        >>> _uniform_nan("<NA>")
+        'nan'
+        >>> _uniform_nan("NaN")
+        'nan'
+    """
+    first_replacement = _lower_nan_representation(cell_text)
+    second_replacement = _replace_enclosed_na_representation(first_replacement)
+    return second_replacement
+
+
 def _get_multi_index_columns(
     multi_index: pandas.MultiIndex, index_formats: str
 ) -> List[_PandasColumn]:
@@ -1881,7 +1957,7 @@ def _format_values_of_series_to_representation(
         format_spec=adjusted_format_spec,
     )
     if series_to_print.hasnans:
-        formatted_values = formatted_values.map(_lower_nan_representation)
+        formatted_values = formatted_values.map(_uniform_nan)
     formatted_values.name = series_to_print.name
     max_item_length = formatted_values.map(len).max()
 
@@ -2864,4 +2940,4 @@ def print_pandas(
             max_line_count=max_line_count,
             max_title_width=max_title_width,
         )
-    )
+    )
\ No newline at end of file
